# DiscordUp
Update and install Discord via the terminal on linux.

# Installation
```
$ pip install discordup
```

# Usage
### Updating Discord 
```
$ discordup
```

### Installing Discord
```
$ discordup -i [stable|ptb|canary|development|all]
```

# FAQ
* **Which distros does it work on?** All those using these standard linux commands: `rm` + `mv` (Ubuntu, Manjaro, Fedora, etc.)